@@ -39,13 +39,21 @@ func (s *stack) dfs(current *Node) {
 	size := s.size()
 	for i := 0; i < size; i++ {
 		parent := s.pop()
-		if !current.isDirectlyUnder(parent) {
-			continue
-		}
 
-		parent.addChild(current)
-		current.setParent(parent)
-		s.push(parent).push(current)
+		// for same name on the same hierarchy
+		if child := parent.findChildByText(current.name); child != nil {
+			if !child.isDirectlyUnder(parent) {
+				continue
+			}
+			s.push(parent).push(child)
+		} else {
+			if !current.isDirectlyUnder(parent) {
+				continue
+			}
+			parent.addChild(current)
+			current.setParent(parent)
+			s.push(parent).push(current)
+		}
 		return
 	}
 }
