@@ -8,10 +8,7 @@ import (
 
 // Output outputs a tree to w with r as Markdown format input.
 func Output(w io.Writer, r io.Reader, options ...Option) error {
-	conf, err := newConfig(options)
-	if err != nil {
-		return err
-	}
+	conf := newConfig(options)
 
 	tree := newTreeSimple(conf)
 	if conf.massive {
@@ -22,10 +19,7 @@ func Output(w io.Writer, r io.Reader, options ...Option) error {
 
 // Mkdir makes directories.
 func Mkdir(r io.Reader, options ...Option) error {
-	conf, err := newConfig(options)
-	if err != nil {
-		return err
-	}
+	conf := newConfig(options)
 
 	tree := newTreeSimple(conf)
 	if conf.massive {
