@@ -33,6 +33,54 @@ func TestOutput_detecting_goroutineleak(t *testing.T) {
 	}
 }
 
+func TestOutput_json_detecting_goroutineleak(t *testing.T) {
+	ctx, cancel := context.WithTimeout(context.Background(), time.Duration(500*time.Millisecond))
+	defer cancel()
+	w := io.Discard
+	r := strings.NewReader(tu.TwentyThousandRoots)
+	if gotErr := gtree.Output(w, r, gtree.WithEncodeJSON(), gtree.WithMassive(ctx)); gotErr != nil {
+		if gotErr != context.DeadlineExceeded {
+			t.Errorf("\ngotErr: \n%v\nwantErr: \n%v", gotErr, context.DeadlineExceeded)
+		}
+	}
+}
+
+func TestOutput_yaml_detecting_goroutineleak(t *testing.T) {
+	ctx, cancel := context.WithTimeout(context.Background(), time.Duration(500*time.Millisecond))
+	defer cancel()
+	w := io.Discard
+	r := strings.NewReader(tu.TwentyThousandRoots)
+	if gotErr := gtree.Output(w, r, gtree.WithEncodeYAML(), gtree.WithMassive(ctx)); gotErr != nil {
+		if gotErr != context.DeadlineExceeded {
+			t.Errorf("\ngotErr: \n%v\nwantErr: \n%v", gotErr, context.DeadlineExceeded)
+		}
+	}
+}
+
+func TestOutput_toml_detecting_goroutineleak(t *testing.T) {
+	ctx, cancel := context.WithTimeout(context.Background(), time.Duration(500*time.Millisecond))
+	defer cancel()
+	w := io.Discard
+	r := strings.NewReader(tu.TwentyThousandRoots)
+	if gotErr := gtree.Output(w, r, gtree.WithEncodeTOML(), gtree.WithMassive(ctx)); gotErr != nil {
+		if gotErr != context.DeadlineExceeded {
+			t.Errorf("\ngotErr: \n%v\nwantErr: \n%v", gotErr, context.DeadlineExceeded)
+		}
+	}
+}
+
+func TestOutput_dryrun_detecting_goroutineleak(t *testing.T) {
+	ctx, cancel := context.WithTimeout(context.Background(), time.Duration(500*time.Millisecond))
+	defer cancel()
+	w := io.Discard
+	r := strings.NewReader(tu.TwentyThousandRoots)
+	if gotErr := gtree.Output(w, r, gtree.WithDryRun(), gtree.WithMassive(ctx)); gotErr != nil {
+		if gotErr != context.DeadlineExceeded {
+			t.Errorf("\ngotErr: \n%v\nwantErr: \n%v", gotErr, context.DeadlineExceeded)
+		}
+	}
+}
+
 type in struct {
 	input   io.Reader
 	options []gtree.Option
@@ -147,6 +195,42 @@ a
 				err: nil,
 			},
 		},
+
+		{
+			name: "case(succeeded/same name on the same hierarchy)",
+			in: in{
+				input: strings.NewReader(strings.TrimSpace(`
+- a
+	- same_a
+		- same_b
+			- k
+			- kk
+		- t
+	- p
+		- q
+	- same_a
+		- o
+		- same_b
+			- ppp
+	- g`))},
+			out: out{
+				output: strings.TrimPrefix(`
+a
+├── same_a
+│   ├── same_b
+│   │   ├── k
+│   │   ├── kk
+│   │   └── ppp
+│   ├── t
+│   └── o
+├── p
+│   └── q
+└── g
+`, "\n"),
+				err: nil,
+			},
+		},
+
 		{
 			name: "case(succeeded/very deeply)",
 			in: in{
@@ -270,11 +354,8 @@ root dir aaa
 			out: out{
 				output: strings.TrimPrefix(`
 parent
-├── child
-│   ├── chilchil
-│   ├── chilchil
-│   └── chilchil
 └── child
+    └── chilchil
 `, "\n"),
 				err: nil,
 			},
@@ -1205,3 +1286,22 @@ children:
 		})
 	}
 }
+
+// TODO: config.go用にtest.goあってもいいんじゃないか
+func TestOutput_nilctx(t *testing.T) {
+	w := io.Discard
+	r := strings.NewReader(tu.SingleRoot)
+	if gotErr := gtree.Output(w, r, gtree.WithMassive(nil)); gotErr != nil {
+		t.Errorf("\ngotErr: \n%v\nwantErr: \n%v", gotErr, nil)
+	}
+}
+
+// TODO: config.go用にtest.goあってもいいんじゃないか
+func TestOutput_nilopt(t *testing.T) {
+	w := io.Discard
+	r := strings.NewReader(tu.SingleRoot)
+	var emptyOpt gtree.Option
+	if gotErr := gtree.Output(w, r, emptyOpt); gotErr != nil {
+		t.Errorf("\ngotErr: \n%v\nwantErr: \n%v", gotErr, nil)
+	}
+}
